#[non_exhaustive]pub enum OAuthClientScope {
ApiFullAccess,
ServerAdministration,
}Available on crate feature
api only.Expand description
An OAuth scope which grants access to some client-server API endpoints.
This enum does not include the device ID scope, which isn’t really a scope (as it doesn’t grant access to anything) but instead a way to reserve a specific device ID.
This type can hold an arbitrary string. To build this with a custom value, convert it from a
string with ::from() / .into(). To check for values that are not available as a
documented variant here, use its string representation, obtained through
.as_str().
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ApiFullAccess
Full access to all endpoints of the client-server API, unless explicitly noted.
ServerAdministration
Available on crate feature
unstable-msc4484 only.Access to the endpoints in the Server Administration module.
Implementations