pub trait OutgoingResponse: Sized {
type Body: OutgoingBody;
// Required method
fn try_into_http_response_inner(
self,
) -> Result<Response<Self::Body>, IntoHttpError>;
}Available on crate feature
api only.Expand description
A request type for a Matrix API endpoint, used for sending responses.
Required Associated Types
Sourcetype Body: OutgoingBody
type Body: OutgoingBody
HTTP body type pre-serialization.
Required Methods
Sourcefn try_into_http_response_inner(
self,
) -> Result<Response<Self::Body>, IntoHttpError>
fn try_into_http_response_inner( self, ) -> Result<Response<Self::Body>, IntoHttpError>
Tries to convert this response into an http::Response.
This method should only fail when invalid header values are specified. It may also fail with a serialization error in case of bugs in Ruma though.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".